#ifndef THANM_H_
#define THANM_H_

#include <stdint.h>
#include <stdio.h>

#define THANM_BGRA8888  1
#define THANM_BGR565    3
#define THANM_BGRA4444  5

/* offsets are from the start of the header */
typedef struct
{
	uint32_t version;     /* 7 */
	uint16_t attrnum;     /* attributes (stored after regions) */
	uint16_t regnum;      /* regions (stored after the header) */
	uint16_t zero1;       /* 0 */
	uint16_t width;       /* image width */
	uint16_t height;      /* image height */
	uint16_t format;      /* image pixel format */
	uint32_t nameoffset;  /* offset to filename */
	uint16_t offsetx;     /* for joining npot images together */
	uint16_t offsety;
	uint32_t unknown1;    /* 0, 10, 11 */
	uint32_t entryoffset; /* offset to image data */
	uint32_t unknown2;    /* 0, 1 */
	uint32_t nextoffset;  /* offset to next header */
	uint8_t zero2[24];    /* 0 */
} thanm_header_t;

typedef struct
{
    uint32_t magic;
    uint16_t unknown1;
    uint16_t format;
    uint16_t width;
    uint16_t height;
    uint32_t size;
} thtx_header_t;

typedef struct
{
	thanm_header_t header;
	char* name;
	unsigned int offset;
} thanm_entry_t;

typedef struct
{
	FILE* stream;
	thanm_entry_t* entries;
} thanm_t;

typedef struct
{
	uint16_t x, y;
	uint32_t w, h;
	unsigned char* data;
	unsigned int offset;
} thanm_image_part_t;

thanm_t* thanm_open(const char* filename);
void thanm_close(thanm_t* anm);

#endif
